@@ -1,6 +1,6 @@
 # ABSTRACT: A simple interface to ArangoDB REST API
 package Arango::DB;
-$Arango::DB::VERSION = '0.001';
+$Arango::DB::VERSION = '0.002';
 use Arango::DB::Database;
 use Arango::DB::Collection;
 
@@ -8,7 +8,7 @@ use strict;
 use warnings;
 use HTTP::Tiny;
 use JSON;
-use MIME::Base64 'encode_base64url';
+use MIME::Base64 3.11 'encode_base64url';
 
 sub new {
     my ($package, %opts) = @_;
@@ -193,7 +193,7 @@ Arango::DB - A simple interface to ArangoDB REST API
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSYS
 
